Ready

Struct Ready 

1.48.0 · Source
pub struct Ready<T>(/* private fields */);
A future that is immediately ready with a value.

This struct is created by ready(). See its documentation for more.

Implementations

Source

impl<T> Ready<T>

1.82.0 · Source

pub fn into_inner(self) -> T

Consumes the Ready, returning the wrapped value.

Panics

Will panic if this Ready was already polled to completion.

Examples
use std::future;

let a = future::ready(1);
assert_eq!(a.into_inner(), 1);